use crate::Instructions;
use std::cell::RefCell;

pub const BOOL_TRUE: Object = Object::Bool(true);
pub const BOOL_FALSE: Object = Object::Bool(false);
pub const NULL: Object = Object::Null;

#[derive(Debug, Clone, PartialEq)]
pub enum Object {
    String(String),
    Number(f64),
    Bool(bool),
    Null,
    Array(RefCell<Vec<Object>>),
    Function(Instructions, usize, usize),
}

impl Object {
    pub fn to_bool(&self) -> bool {
        match self {
            Object::Bool(b) => *b,
            _ => todo!()
        }
    }

    pub fn some(self) -> Option<Self> {
        Some(self)
    }
}